Documentation
¶
Index ¶
Constants ¶
const MinimumVMStorageSize = 1024 * 1024 * 128
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type APIResponse ¶
type AuthConfig ¶ added in v0.2.1
type AuthConfig struct {
EnablePAM bool `json:"enablePAM"`
}
type BaseConfigAdmin ¶
type BulkDeleteRequest ¶ added in v0.3.0
type BulkDeleteRequest struct {
IDs []int `json:"ids" binding:"required"`
}
type BulkUpdateRulesRequest ¶ added in v0.3.0
type Environment ¶ added in v0.1.0
type Environment string
const ( Development Environment = "development" Production Environment = "production" Debug Environment = "debug" )
type JailsConfig ¶ added in v0.3.0
type JailsConfig struct {
DisableDevFS bool `json:"disableDevFS"`
}
type NoteRequest ¶ added in v0.3.0
type SylveConfig ¶
type SylveConfig struct {
Environment Environment `json:"environment"`
ProxyToVite bool `json:"proxyToVite"`
Profile bool `json:"profile"`
IP string `json:"ip"`
Port int `json:"port"`
HTTPPort int `json:"httpPort"`
LogLevel int8 `json:"logLevel"`
WANInterfaces []string `json:"wanInterfaces"`
Admin BaseConfigAdmin `json:"admin"`
DataPath string `json:"dataPath"`
TLS *TLSConfig `json:"tlsConfig,omitempty"`
Raft Raft `json:"raft"`
BTT BTT `json:"btt"`
Auth AuthConfig `json:"auth"`
Jails JailsConfig `json:"jails"`
ZFS ZFSConfig `json:"zfs"`
Uploads UploadsConfig `json:"uploads"`
TrustedProxies []string `json:"trustedProxies"`
}
type UploadsConfig ¶ added in v0.3.0
Directories
¶
| Path | Synopsis |
|---|---|
|
replicationguard
Package replicationguard tracks which replication safety tables have completed schema initialization for a concrete database connection.
|
Package replicationguard tracks which replication safety tables have completed schema initialization for a concrete database connection. |
|
interfaces
|
|
Click to show internal directories.
Click to hide internal directories.